@@ -1,7 +1,5 @@
 use strict;
 
-use FindBin qw/$Bin/;
-use lib '$Bin/../lib';
 use SkypeAPI::Robot;
 use Data::Dumper;
 
